ProgressHud class

show progresshud like ios app

Inheritance

Constructors

ProgressHud({Key? key, required Widget child, double offsetY = -50, bool isGlobalHud = false, Duration? maximumDismissDuration})

Properties

child → Widget
final
hashCode → int
The hash code for this object.
no setterinherited
isGlobalHud → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maximumDismissDuration → Duration?
final
offsetY → double
the offsetY of hudview postion from center, default is -50
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → ProgressHudState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

dismiss() → void
dismiss hud
of(BuildContext context) → ProgressHudState?
show(ProgressHudType type, String text) → void
show hud with type and text
showAndDismiss(ProgressHudType type, String text) → Future
show hud and dismiss automatically
showErrorAndDismiss({required String text}) → Future
show error icon with text and dismiss automatic
showLoading({String text = "loading"}) → void
show loading with text
showSuccessAndDismiss({required String text}) → Future
show success icon with text and dismiss automatic
showToast({required String text}) → Future
show toast text and dismiss automatic
updateProgress(double progress, String text) → void
update progress value and text when ProgressHudType = progress